==> plumed-2.2b.tgz: plumed-2.2b/src/reference/DotProductDistance.cpp <==
/* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
   Copyright (c) 2012-2015 The plumed team
   (see the PEOPLE file at the root of the distribution for a list of names)

   See http://www.plumed-code.org for more information.

   This file is part of plumed, version 2.

   plumed is free software: you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   plumed is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public License
   along with plumed.  If not, see <http://www.gnu.org/licenses/>.
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
#include "MetricRegister.h"
#include "ArgumentOnlyDistance.h"
#include "core/Value.h"

namespace PLMD {

class DotProductDistance : public ArgumentOnlyDistance {
public:
  DotProductDistance( const ReferenceConfigurationOptions& ro );
  void read( const PDB& );
  double calc( const std::vector<Value*>& vals, const std::vector<double>& arg, const bool& squared );
};

PLUMED_REGISTER_METRIC(DotProductDistance,"DOTPRODUCT")

DotProductDistance::DotProductDistance( const ReferenceConfigurationOptions& ro ):
ReferenceConfiguration(ro),
ArgumentOnlyDistance(ro)
{
}

void DotProductDistance::read( const PDB& pdb ){
  readArgumentsFromPDB( pdb );
}

double DotProductDistance::calc( const std::vector<Value*>& vals, const std::vector<double>& arg, const bool& squared ){
  double dot=0.0; 
  for (unsigned long i=0; i<vals.size(); ++i) dot+=getReferenceArgument(i)*arg[i];
  return -log(dot);
}


}

==> plumed-2.7.3.tgz: plumed-2.7.3/src/reference/DotProductDistance.cpp <==
/* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
   Copyright (c) 2015-2021 The plumed team
   (see the PEOPLE file at the root of the distribution for a list of names)

   See http://www.plumed.org for more information.

   This file is part of plumed, version 2.

   plumed is free software: you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   plumed is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public License
   along with plumed.  If not, see <http://www.gnu.org/licenses/>.
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
#include "MetricRegister.h"
#include "ArgumentOnlyDistance.h"
#include "core/Value.h"

namespace PLMD {

class DotProductDistance : public ArgumentOnlyDistance {
public:
  explicit DotProductDistance( const ReferenceConfigurationOptions& ro );
  void read( const PDB& ) override;
  double calculateArgumentDistance( const std::vector<Value*> & vals, const std::vector<double>& arg, ReferenceValuePack& myder, const bool& squared ) const override;
};

PLUMED_REGISTER_METRIC(DotProductDistance,"DOTPRODUCT")

DotProductDistance::DotProductDistance( const ReferenceConfigurationOptions& ro ):
  ReferenceConfiguration(ro),
  ArgumentOnlyDistance(ro)
{
}

void DotProductDistance::read( const PDB& pdb ) {
  readArgumentsFromPDB( pdb );
}

double DotProductDistance::calculateArgumentDistance( const std::vector<Value*> & vals, const std::vector<double>& arg,
    ReferenceValuePack& myder, const bool& squared ) const {
  double dot=0.0;
  for (unsigned long i=0; i<vals.size(); ++i) dot+=getReferenceArgument(i)*arg[i];
  for (unsigned long i=0; i<vals.size(); ++i) myder.setArgumentDerivatives( i, -getReferenceArgument(i)/dot );
  return -log(dot);
}


}
